==> hicp_1.0.0.tar.gz: hicp/man/linking.Rd <==
\name{linking}

\alias{link}
\alias{lsf}

\title{Linking-in new index series}

\author{Sebastian Weinand}

\description{
Function \code{link()} links a new index series (\code{x.new}) to an existing one (\code{x}) using the overlap periods in \code{t.overlap}. In the resulting linked index series, the new index series starts after the existing one.

Function \code{lsf()} computes the level-shift factors for linking via the overlap periods in \code{t.overlap} in comparison to the one-month overlap method using December of year \code{t-1}. The level-shift factors can then be used to shift the index level of a HICP index series.}

\usage{
link(x, x.new, t, t.overlap=NULL, settings=list())

lsf(x, x.new, t, t.overlap=NULL, settings=list())
}

\arguments{
  \item{x, x.new}{numeric vector of index values. \code{NA}-values in the vectors indicate when the index series discontinues (for \code{x}) or starts (for \code{x.new}).}
  \item{t}{date vector in format \code{YYYY-MM-DD} with monthly frequency, that is, one observation per month. Quarterly and yearly frequencies are also supported.}
  \item{t.overlap}{character specifying the overlap period either in format \code{YYYY} for a calendar year or \code{YYYY-MM} for a specific month or quarter. Multiple periods can be provided. If \code{NULL}, all intersecting periods in \code{x} and \code{x.new} are used.}
  \item{settings}{list of control settings to be used. The following settings are supported:
  \itemize{
    \item \code{chatty} : logical indicating if package-specific warnings and info messages should be printed or not. The default is \code{getOption("hicp.chatty")}.
    \item \code{freq} : character specifying the frequency of \code{t}. Allowed values are \code{month}, \code{quarter}, \code{year}, and \code{auto} (the default). For \code{auto}, the frequency is internally derived from \code{t}.
    \item \code{na.rm} : logical indicating if averages for calendar years should also be computed when there are \code{NA}s and less than 12 months (or 4 quarters) present (for \code{na.rm=TRUE}).
    }}
}

\value{
Function \code{link()} returns a numeric vector or a matrix of the same length as \code{t}, while \code{lsf()} provides a named numeric vector of the same length as \code{t.overlap}.
}

\seealso{
\code{\link{chain}}
}

\examples{
# input data:
set.seed(1)
t <- seq.Date(from=as.Date("2015-01-01"), to=as.Date("2024-05-01"), by="1 month")
x.new <- rnorm(n=length(t), mean=100, sd=5)
x.new <- rebase(x=x.new, t=t, t.ref="2019-12")
x.old <- x.new + rnorm(n=length(x.new), sd=5)
x.old <- rebase(x=x.old, t=t, t.ref="2015")
x.old[t>as.Date("2021-12-01")] <- NA # current index discontinues in 2021
x.new[t<as.Date("2020-01-01")] <- NA # new index starts in 2019-12

# linking in new index in different periods:
matplot(x=t, 
        y=link(x=x.old, x.new=x.new, t=t, t.overlap=c("2021-12","2020","2021")), 
        col=c("red","blue","green"), type="l", lty=1, 
        xlab=NA, ylab="Index", ylim=c(80,120))
lines(x=t, y=x.old, col="black")
abline(v=as.Date("2021-12-01"), lty="dashed")
legend(x="topleft",
       legend=c("One-month overlap using December 2021",
                "Annual overlap using 2021",
                "Annual overlap using 2020"),
       fill=c("red","green","blue"), bty = "n")

# compute level-shift factors:
lsf(x=x.old, x.new=x.new, t=t, t.overlap=c("2020","2021"))

# level-shift factors can be applied to already chain-linked index series
# to obtain linked series using another overlap period:
x.new.chained <- link(x=x.old, x.new=x.new, t=t, t.overlap="2021-12")

# level-shift adjustment:
x.new.adj <- ifelse(test=t>as.Date("2021-12-01"),
                    yes=x.new.chained*lsf(x=x.old, x.new=x.new, t=t, t.overlap="2020"),
                    no=x.new.chained)

# compare:
all.equal(x.new.adj, link(x=x.old, x.new=x.new, t=t, t.overlap="2020"))
}

==> hicp_1.1.0.tar.gz: hicp/man/linking.Rd <==
\name{linking}

\alias{link}
\alias{lsf}

\title{Linking-in new index series}

\author{Sebastian Weinand}

\description{
The function \code{link()} links a new index series (\code{x.new}) to an existing one (\code{x}) using the overlap periods in \code{t.overlap}. 
In the resulting linked index series, the new index series starts after the existing one.

The function \code{lsf()} computes the level-shift factors for linking via the overlap periods in \code{t.overlap} in comparison to the standard one-month overlap method using December of year \code{t-1}.
The level-shift factors can then be used to shift the index level of a HICP index series.
}

\usage{
link(x, x.new, t, t.overlap=NULL, settings=list())

lsf(x, x.new, t, t.overlap=NULL, settings=list())
}

\arguments{
  \item{x, x.new}{numeric vector of index values. \code{NA}-values in the vectors indicate when the index series discontinues (for \code{x}) or starts (for \code{x.new}).}
  \item{t}{date vector of monthly (i.e., one observation per month), quarterly or yearly frequency in format \code{YYYY-MM-DD}.}
  \item{t.overlap}{character specifying the overlap period either in format \code{YYYY} for a calendar year or \code{YYYY-MM} for a specific month or quarter. Multiple periods can be provided. If \code{NULL}, all intersecting periods in \code{x} and \code{x.new} are used.}
  \item{settings}{list of control settings to be used. The following settings are supported:
  \itemize{
    \item \code{chatty} : logical indicating if package-specific warnings and info messages should be printed or not. The default is \code{getOption("hicp.chatty")}.
    \item \code{freq} : character specifying the frequency of \code{t}. Allowed values are \code{month}, \code{quarter}, \code{year}, and \code{auto} (the default). For \code{auto}, the frequency is internally derived from \code{t}.
    \item \code{na.rm} : logical indicating if averages for calendar years should also be computed when there are \code{NA}s and less than 12 months (or 4 quarters) present (for \code{na.rm=TRUE}).
    }}
}

\value{
The function \code{link()} returns a numeric vector or a matrix of the same length as \code{t}, while \code{lsf()} provides a named numeric vector of the same length as \code{t.overlap}.
}

\seealso{
\code{\link{chain}}
}

\examples{
# input data:
set.seed(1)
t <- seq.Date(from=as.Date("2015-01-01"), to=as.Date("2024-05-01"), by="1 month")
x.new <- rnorm(n=length(t), mean=100, sd=5)
x.new <- rebase(x=x.new, t=t, t.ref="2019-12")
x.old <- x.new + rnorm(n=length(x.new), sd=5)
x.old <- rebase(x=x.old, t=t, t.ref="2015")
x.old[t>as.Date("2021-12-01")] <- NA # current index discontinues in 2021
x.new[t<as.Date("2020-01-01")] <- NA # new index starts in 2019-12

# linking in new index in different periods:
matplot(x=t, 
        y=link(x=x.old, x.new=x.new, t=t, t.overlap=c("2021-12","2020","2021")), 
        col=c("red","blue","green"), type="l", lty=1, 
        xlab=NA, ylab="Index", ylim=c(80,120))
lines(x=t, y=x.old, col="black")
abline(v=as.Date("2021-12-01"), lty="dashed")
legend(x="topleft",
       legend=c("One-month overlap using December 2021",
                "Annual overlap using 2021",
                "Annual overlap using 2020"),
       fill=c("red","green","blue"), bty = "n")

# compute level-shift factors:
lsf(x=x.old, x.new=x.new, t=t, t.overlap=c("2020","2021"))

# level-shift factors can be applied to already chain-linked index series
# to obtain linked series using another overlap period:
x.new.chained <- link(x=x.old, x.new=x.new, t=t, t.overlap="2021-12")

# level-shift adjustment:
x.new.adj <- ifelse(test=t>as.Date("2021-12-01"),
                    yes=x.new.chained*lsf(x=x.old, x.new=x.new, t=t, t.overlap="2020"),
                    no=x.new.chained)

# compare:
all.equal(x.new.adj, link(x=x.old, x.new=x.new, t=t, t.overlap="2020"))
}
